package com.company.onboarding.screen.imagesgrid;

import com.company.onboarding.entity.User;
import io.jmix.core.FileRef;
import io.jmix.ui.UiComponents;
import io.jmix.ui.component.FileStorageResource;
import io.jmix.ui.component.GridLayout;
import io.jmix.ui.component.HBoxLayout;
import io.jmix.ui.component.Image;
import io.jmix.ui.model.CollectionContainer;
import io.jmix.ui.screen.Screen;
import io.jmix.ui.screen.Subscribe;
import io.jmix.ui.screen.UiController;
import io.jmix.ui.screen.UiDescriptor;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;

@UiController("ImagesGridScreen")
@UiDescriptor("images-grid-screen.xml")
public class ImagesGridScreen extends Screen {

    public static final int COL_COUNT = 2;

    @Autowired
    private CollectionContainer<User> usersDc;
    @Autowired
    private UiComponents uiComponents;
    @Autowired
    private HBoxLayout container;

    @Subscribe
    public void onAfterShow(AfterShowEvent event) {
        List<User> users = usersDc.getItems();

        GridLayout gridLayout = uiComponents.create(GridLayout.class);
        gridLayout.setColumns(COL_COUNT);

        int rowsCount = (int) Math.ceil((double) users.size() / COL_COUNT);
        gridLayout.setRows(rowsCount);

        for (int i = 0; i < users.size(); i++) {
            int row = i / COL_COUNT;
            int col = i % COL_COUNT;

            Image image = uiComponents.create(Image.class);
            image.setWidth("100px");
            image.setHeight("100px");
            image.setScaleMode(Image.ScaleMode.CONTAIN);

            User user = users.get(i);
            FileRef fileRef = user.getPicture();
            if (fileRef != null) {
                image.setSource(FileStorageResource.class).setFileReference(fileRef);
            }
            gridLayout.add(image, col, row);
        }

        container.add(gridLayout);
    }


}